.. Copyright (C) 2013 Branko Majic

   This file is part of Django Conntrackt documentation.

   This work is licensed under the Creative Commons Attribution-ShareAlike 3.0
   Unported License. To view a copy of this license, visit
   http://creativecommons.org/licenses/by-sa/3.0/ or send a letter to Creative
   Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.


Django Conntrackt documentation
===============================

Django Conntrackt is a simple application intended to provide system
administrators and integrators that deploy servers at client's premises to
easily keep track of required networ communications between different servers,
routers, client workstations, and even whole networks/sub-networks.


Support
-------

In case of problems with the application, please do not hesitate to contact the
author at **django.conntrackt (at) majic.rs**. Known issues and planned features
are tracked on website:

* https://projects.majic.rs/conntrackt

The library is hosted on author's own server, alongside a mirror on
Bitbucket:

* https://code.majic.rs/conntrackt
* https://bitbucket.org/redpenguin/conntrackt


License
-------

Django Conntrackt *application* is licensed under the terms of GPLv3, or (at
your option) any later version. You should have received the full copy of the
GPLv3 license in the local file **LICENSE-GPLv3**, or you may read the full text
of the license at:

* http://www.gnu.org/licenses/gpl-3.0.txt

Django Conntrackt *documentation* is licensed under the terms of CC-BY-SA 3.0
Unported license. You should have received the full copy of the CC-BY-SA 3.0
Unported in the local file **LICENSE-CC-BY-SA-3.0-Unported**, or you may read
the full text of the license at:

http://creativecommons.org/licenses/by-sa/3.0/

The following third-party libraries are included as part of Django Conntrackt,
but are distributed under their own license:

Bootstrap (sub-directory **conntrackt/static/bootstrap**)
  Apache License v2.0
jQuery (file **conntrackt/static/jquery-min.js**)
  MIT License


Contents
--------

.. toctree::
   :maxdepth: 2

   about
   installation
   quickstart
   usage
   development
   releaseprocedures
   releasenotes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

